from ij import IJ  # pylint: disable=import-error


def open_sequence_as_hyperstack(sequence):
    hyperstack = IJ.createHyperStack(sequence.id, sequence.width, sequence.height, sequence.num_channels, sequence.num_slices, sequence.num_frames, sequence.num_bits_per_pixels)
    for channel_index in range(sequence.num_channels):
        for frame_index in range(sequence.num_frames):
            slice_index = 0
            src_image_file_path = sequence.get_image_file_path(channel_index=channel_index, frame_index=frame_index)
            # print(src_image_file_path)
            src_image = IJ.openImage(src_image_file_path)
            # print(src_image.getProperties())
            hyperstack.setPositionWithoutUpdate(channel_index + 1, slice_index + 1, frame_index + 1)
            hyperstack.setProcessor(src_image.getProcessor())
    return hyperstack

def open_sequence_as_stack(sequence, channel_id):
    '''
    :param str channel_id: eg 'DM300_327-353_fluo'
    '''
    channel_index = sequence.get_channel_index(channel_id)
    hyperstack = IJ.createHyperStack(sequence.id, sequence.width, sequence.height, 1, sequence.num_slices, sequence.num_frames, sequence.num_bits_per_pixels)
    for frame_index in range(sequence.num_frames):
        slice_index = 0
        src_image_file_path = sequence.get_image_file_path(channel_index=channel_index, frame_index=frame_index)
        # print(src_image_file_path)
        src_image = IJ.openImage(src_image_file_path)
        # print(src_image.getProperties())
        hyperstack.setPositionWithoutUpdate(channel_index + 1, slice_index + 1, frame_index + 1)
        hyperstack.setProcessor(src_image.getProcessor())
    return hyperstack

def open_sequence_in_imagej(sequence):
    # ip = IJ.createHyperStack(title=sequence.id, width=sequence.width, height= sequence.height, channels=1, slices=1, frames=sequence.get_num_frames(), bitdepth=16)
    hyperstack = open_sequence_as_hyperstack(sequence)
    hyperstack.show()
    for channel_index in range(sequence.num_channels):
        hyperstack.setPositionWithoutUpdate(channel_index + 1, 1, 1)
        IJ.run("Enhance Contrast", "saturated=0.35")
    return hyperstack
